==> nextcloud-14.0.13.zip: nextcloud/apps/files_external/l10n/gl.js <==
OC.L10N.register(
    "files_external",
    {
    "External storages" : "Almacenamentos externos",
    "Personal" : "Persoal",
    "System" : "Sistema",
    "Grant access" : "Permitir o acceso",
    "Error configuring OAuth1" : "Produciuse un erro ao configurar OAuth1",
    "Please provide a valid app key and secret." : "Forneza unha chave de aplicativo e a chave secreta.",
    "Error configuring OAuth2" : "Produciuse un erro ao configurar OAuth2",
    "Generate keys" : "Xerar chaves",
    "Error generating key pair" : "Produciuse un erro ao xerar o par de chaves",
    "All users. Type to select user or group." : "Todos os usuarios. Escriba para seleccionar usuario ou grupo.",
    "(group)" : "(grupo)",
    "Compatibility with Mac NFD encoding (slow)" : "Compatibilidade coa codificación Mac MFD (lenta)",
    "Enable encryption" : "Activar o cifrado",
    "Enable previews" : "Activar as vistas previas",
    "Enable sharing" : "Activar as comparticións",
    "Check for changes" : "Comprobar se hai cambios",
    "Never" : "Nunca",
    "Once every direct access" : "Unha vez cada acceso directo",
    "Read only" : "Só lectura",
    "Delete" : "Eliminar",
    "Admin defined" : "Definido polo administrador",
    "Are you sure you want to delete this external storage?" : "Confirma que quere eliminar este almacenamento externo?",
    "Delete storage?" : "Eliminar o almacenamento?",
    "Saved" : "Gardado",
    "Saving..." : "Gardando…",
    "Save" : "Gardar",
    "Empty response from the server" : "Resposta baleira dende o servidor",
    "Couldn't access. Please log out and in again to activate this mount point" : "Non é posíbel acceder. Peche a sesión e volva iníciala para activar este punto de montaxe",
    "Couldn't get the information from the remote server: {code} {type}" : "Non foi posíbel obter a información do servidor remoto: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "Non foi posíbel obter a lista dos puntos de montaxe externos: {type}",
    "There was an error with message: " : "produciuse un erro coa mensaxe:",
    "External mount error" : "Produciuse un erro de montaxe externo",
    "external-storage" : "almacenamento externo",
    "Couldn't fetch list of Windows network drive mount points: Empty response from server" : "Non é posíbel obter a lista de unidades de rede e os seus puntos de montaxe de Windows: resposta baleira dende o servidor",
    "Please enter the credentials for the {mount} mount" : "Introduza as credenciais para o punto de montaxe {mount}",
    "Username" : "Nome de usuario",
    "Password" : "Contrasinal",
    "Credentials saved" : "Credenciais gardadas",
    "Credentials saving failed" : "Non foi posíbel gardar as credenciais",
    "Credentials required" : "Requírense as credenciais",
    "Storage with ID \"%d\" not found" : "Non se atopa o almacenamento co ID «%d» ",
    "Invalid backend or authentication mechanism class" : "Clase de mecanismo de autenticación ou infraestrutura incorrecta",
    "Invalid mount point" : "Punto de montaxe incorrecto",
    "Objectstore forbidden" : "Almacén de obxectos non admitido",
    "Invalid storage backend \"%s\"" : "Infraestrutura de almacenamento «%s» incorrecta",
    "Not permitted to use backend \"%s\"" : "Non está permitido empregar a infraestrutura «%s»",
    "Not permitted to use authentication mechanism \"%s\"" : "Non está permitido empregar o mecanismo de autenticación «%s»",
    "Unsatisfied backend parameters" : "Os parámetros da infraestrutura non son satisfactorios",
    "Unsatisfied authentication mechanism parameters" : "Os parámetros do mecanismo de autenticación non son satisfactorios",
    "Insufficient data: %s" : "Faltan datos: %s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not user editable" : "O almacenamento co ID «%d» non pode ser editado polo usuario",
    "Access key" : "Chave de acceso",
    "Secret key" : "Chave secreta",
    "Builtin" : "Integrado",
    "None" : "Ningún",
    "OAuth1" : "OAuth1",
    "App key" : "Clave da API",
    "App secret" : "Secreto do aplicativo",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID do cliente",
    "Client secret" : "Secreto do cliente",
    "OpenStack v2" : "OpenStack v2",
    "Tenant name" : "Nome do ocupante",
    "Identity endpoint URL" : "URL do punto final de identidade",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "Dominio",
    "Rackspace" : "Espazo no estante",
    "API key" : "Chave da API",
    "Global credentials" : "Credenciais globais",
    "Log-in credentials, save in database" : "Credenciais de acceso, gardar na base de datos",
    "Username and password" : "Nome de usuario e contrasinal",
    "Log-in credentials, save in session" : "Credenciais de acceso, gardar na sesión",
    "User entered, store in database" : "Usuario que accedeu, almacenar na base de datos",
    "RSA public key" : "Chave pública RSA",
    "Public key" : "Chave pública",
    "RSA private key" : "Chave privada RSA",
    "Private key" : "Chave privada",
    "Kerberos ticket" : "Billete Kerberos",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Nome de máquina",
    "Port" : "Porto",
    "Region" : "Rexión",
    "Enable SSL" : "Activar SSL",
    "Enable Path Style" : "Activar o estilo de ruta",
    "Legacy (v2) authentication" : "Autenticación (v2) herdada\n",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Subcartafol remoto",
    "Secure https://" : "https:// seguro",
    "FTP" : "FTP",
    "Host" : "Servidor",
    "Secure ftps://" : "ftps:// seguro",
    "Local" : "Local",
    "Location" : "Localización",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Root (raíz)",
    "SFTP with secret key login" : "SFTP con chave secreta de acceso",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Compartir",
    "Show hidden files" : "Amosar os ficheiros agochados",
    "SMB / CIFS using OC login" : "SMB / CIFS usando acceso OC",
    "Username as share" : "Nome de usuario como compartición",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Nome do servicio",
    "Request timeout (seconds)" : "Tempo de espera da solicitude (segundos)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "A compatibilidade de cURL en PHP non está activada, ou non está instalado. Non é posíbel a montaxe de %s. Consulte co administrador do sistema como instalalo.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "A compatibilidade de FTP en PHP non está activada, ou non está instalado. Non é posíbel a montaxe de %s. Consulte co administrador do sistema como instalalo.",
    "\"%1$s\" is not installed. Mounting of %2$s is not possible. Please ask your system administrator to install it." : "«%1$s» non está instalado. Non é posíbel a montaxe de %2$s. Consulte co administrador do sistema como instalalo.",
    "External storage support" : "Compatibilidade de almacenamento externo",
    "Adds basic external storage support" : "Engade compatibilidade básica de almacenamento externo\n",
    "This application enables administrators to configure connections to external storage providers, such as FTP servers, S3 or SWIFT object stores, other Nextcloud servers, WebDAV servers, and more. Administrators can choose which types of storage to enable and can mount these storage locations for a user, a group, or the entire system. Users will see a new folder appear in their root Nextcloud directory, which they can access and use like any other Nextcloud folder. External storage also allows users to share files stored in these external locations. In these cases, the credentials for the owner of the file are used when the recipient requests the file from external storage, thereby ensuring that the recipient can access the shared file.\n\nExternal storage can be configured using the GUI or at the command line. This second option provides the advanced user with more flexibility for configuring bulk external storage mounts and setting mount priorities. More information is available in the external storage GUI documentation and the external storage Configuration File documentation." : "Este aplicativo permítelle aos administradores configurar conexións a provedores externos de almacenamento, como servidores FTP, almacenamentos de obxectos S3 ou SWIFT, outros servidores Nextcloud, servidores WebDAV e máis. Os administradores poden escoller que tipos de almacenamento activar e poden montar estas localizacións de almacenamento para un usuario, un grupo ou o sistema enteiro. Os usuarios verán aparecer un novo cartafol no seu directorio raíz do Nextcloud, ao que poden acceder e que poden usar como calquera outro cartafol. O almacenamento externo tamén lle permite aos usuarios compartir os ficheiros almacenados nestas localizacións externas. Nestes casos, úsanse as credenciais para o dono dos ficheiros cando o receptor solicita o ficheiro do almacenamento externo, asegurando así que o receptor poida acceder ao ficheiro compartido.\n\nO almacenamento externo pódese configurar usando a IGU ou coa liña de ordes. A segunda opción fornece ao usuario avanzado máis flexibilidade para configurar montaxes de almacenamento externos en bloque e para configurar prioridades de montaxe. Ten dispoñíbel máis información na documentación da IGU do almacenamento externo e na documentación do ficheiro de configuración do almacenamento externo.",
    "No external storage configured or you don't have the permission to configure them" : "No foi configurado ningún almacenamento externo ou non ten permiso para configuralos\n",
    "Name" : "Nome",
    "Storage type" : "Tipo de almacenamento",
    "Scope" : "Ámbito",
    "External storage enables you to mount external storage services and devices as secondary Nextcloud storage devices. You may also allow users to mount their own external storage services." : "O almacenamento externo permítelle montar servizos e dispositivos de almacenamento externo como dispositivos de almacenamento secundarios do Nextcloud. Tamén pode permitirlle que os usuarios monten os seus propios servizos de almacenamento externos.",
    "Folder name" : "Nome do cartafol",
    "External storage" : "Almacenamento externo",
    "Authentication" : "Autenticación",
    "Configuration" : "Configuración",
    "Available for" : "Dispoñíbel para",
    "Click to recheck the configuration" : "Prema para volver comprobar a configuración\n",
    "Add storage" : "Engadir almacenamento",
    "Advanced settings" : "Axustes avanzados",
    "Allow users to mount external storage" : "Permitirlle aos usuarios montar almacenamento externo",
    "Global credentials can be used to authenticate with multiple external storages that have the same credentials." : "Poden empregarse credenciais globais para autenticar con múltiples almacenamentos externos que teñan as mesmas credenciais.",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Algúns dos puntos de montaxe externos configurados non están conectados. Prema na(s) fila(s) vermella(s)  para obter máis información",
    "\"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "«%s» non está instalado. Non é posíbel a montaxe de %s. Consulte co administrador do sistema como instalalo."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.0.zip: nextcloud/apps/files_external/l10n/gl.js <==
OC.L10N.register(
    "files_external",
    {
    "External storages" : "Almacenamentos externos",
    "Personal" : "Persoal",
    "System" : "Sistema",
    "Grant access" : "Permitir o acceso",
    "Error configuring OAuth1" : "Produciuse un erro ao configurar OAuth1",
    "Please provide a valid app key and secret." : "Forneza unha chave de aplicación e a chave secreta.",
    "Error configuring OAuth2" : "Produciuse un erro ao configurar OAuth2",
    "Generate keys" : "Xerar chaves",
    "Error generating key pair" : "Produciuse un erro ao xerar o par de chaves",
    "All users. Type to select user or group." : "Todos os usuarios. Escriba para seleccionar usuario ou grupo.",
    "(group)" : "(grupo)",
    "Compatibility with Mac NFD encoding (slow)" : "Compatibilidade coa codificación Mac MFD (lenta)",
    "Enable encryption" : "Activar o cifrado",
    "Enable previews" : "Activar as vistas previas",
    "Enable sharing" : "Activar as comparticións",
    "Check for changes" : "Comprobar se hai cambios",
    "Never" : "Nunca",
    "Once every direct access" : "Unha vez cada acceso directo",
    "Delete" : "Eliminar",
    "Admin defined" : "Definido polo administrador",
    "Saved" : "Gardado",
    "Saving..." : "Gardando...",
    "Save" : "Gardar",
    "Empty response from the server" : "Resposta baleira desde o servidor",
    "Couldn't get the information from the remote server: {code} {type}" : "Non foi posíbel obter a información do servidor remoto: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "Non foi posíbel obter a lista dos puntos de montaxe externos: {type}",
    "There was an error with message: " : "produciuse un erro coa mensaxe:",
    "External mount error" : "Produciuse un erro de montaxe externo",
    "external-storage" : "almacenamento externo",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Algúns dos puntos de montaxe externos configurados non están conectados. Prema na(s) fila(s) vermella(s)  para obter máis información",
    "Please enter the credentials for the {mount} mount" : "Insira as credenciais para o punto de montaxe {mount}",
    "Username" : "Nome de usuario",
    "Password" : "Contrasinal",
    "Credentials saved" : "Credenciais gardadas",
    "Credentials saving failed" : "Non foi posíbel gardar as credenciais",
    "Credentials required" : "Requírense as credenciais",
    "Storage with ID \"%d\" not found" : "Non se atopa o almacenamento co ID «%d» ",
    "Invalid backend or authentication mechanism class" : "Clase de mecanismo de autenticación ou infraestrutura incorrecta",
    "Invalid mount point" : "Punto de montaxe incorrecto",
    "Objectstore forbidden" : "Almacén de obxectos non admitido",
    "Invalid storage backend \"%s\"" : "Infraestrutura de almacenamento «%s» incorrecta",
    "Not permitted to use backend \"%s\"" : "Non está permitido empregar a infraestrutura «%s»",
    "Not permitted to use authentication mechanism \"%s\"" : "Non está permitido empregar o mecanismo de autenticación «%s»",
    "Unsatisfied backend parameters" : "Os parámetros da infraestrutura non son satisfactorios",
    "Unsatisfied authentication mechanism parameters" : "Os parámetros do mecanismo de autenticación non son satisfactorios",
    "Insufficient data: %s" : "Faltan datos: %s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not user editable" : "O almacenamento co ID «%d» non pode ser editado polo usuario",
    "Access key" : "Chave de acceso",
    "Secret key" : "Chave secreta",
    "Builtin" : "Integrado",
    "None" : "Ningún",
    "OAuth1" : "OAuth1",
    "App key" : "Clave da API",
    "App secret" : "Secreto da aplicación",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID do cliente",
    "Client secret" : "Secreto do cliente",
    "Tenant name" : "Nome do ocupante",
    "Identity endpoint URL" : "URL do punto final de identidade",
    "Domain" : "Dominio",
    "Rackspace" : "Rackspace",
    "API key" : "Chave da API",
    "Global credentials" : "Credenciais globais",
    "Log-in credentials, save in database" : "Credenciais de acceso, gardar na base de datos",
    "Username and password" : "Nome de usuario e contrasinal",
    "Log-in credentials, save in session" : "Credenciais de acceso, gardar na sesión",
    "User entered, store in database" : "Usuario que accedeu, almacenar na base de datos",
    "RSA public key" : "Chave pública RSA",
    "Public key" : "Chave pública",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Nome de máquina",
    "Port" : "Porto",
    "Region" : "Rexión",
    "Enable SSL" : "Activar SSL",
    "Enable Path Style" : "Activar o estilo de ruta",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Subcartafol remoto",
    "Secure https://" : "https:// seguro",
    "FTP" : "FTP",
    "Host" : "Servidor",
    "Secure ftps://" : "ftps:// seguro",
    "Local" : "Local",
    "Location" : "Localización",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Root (raíz)",
    "SFTP with secret key login" : "SFTP con chave secreta de acceso",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Compartir",
    "SMB / CIFS using OC login" : "SMB / CIFS usando acceso OC",
    "Username as share" : "Nome de usuario como compartición",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Nome do servicio",
    "Request timeout (seconds)" : "Tempo de espera da solicitude (segundos)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "A compatibilidade de cURL en PHP non está activada, ou non está instalado. Non é posíbel a montaxe de %s. Consulte co administrador do sistema como instalalo.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "A compatibilidade de FTP en PHP non está activada, ou non está instalado. Non é posíbel a montaxe de %s. Consulte co administrador do sistema como instalalo.",
    "External storage support" : "Compatibilidade de almacenamento externo",
    "Name" : "Nome",
    "Storage type" : "Tipo de almacenamento",
    "Scope" : "Ámbito",
    "Folder name" : "Nome do cartafol",
    "External storage" : "Almacenamento externo",
    "Authentication" : "Autenticación",
    "Configuration" : "Configuración",
    "Available for" : "Dispoñíbel para",
    "Add storage" : "Engadir almacenamento",
    "Advanced settings" : "Axustes avanzados",
    "Allow users to mount external storage" : "Permitirlle aos usuarios montar almacenamento externo",
    "OpenStack" : "OpenStack",
    "\"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "«%s»  non está instalado. Non é posíbel a montaxe de %s. Consulte co administrador do sistema como instalalo.",
    "Allow users to mount the following external storage" : "Permitirlle aos usuarios montar o seguinte almacenamento externo"
},
"nplurals=2; plural=(n != 1);");
